@@ -2,7 +2,7 @@ import asyncio
 import traceback
 from abc import ABC, abstractmethod
 from datetime import datetime
-from typing import List, Type
+from typing import Collection, List, Type
 
 from metaphor.models.crawler_run_metadata import CrawlerRunMetadata, Status
 from metaphor.models.metadata_change_event import MetadataChangeEvent
@@ -11,6 +11,7 @@ from metaphor.common.logger import get_logger
 
 from .api_sink import ApiSink
 from .base_config import BaseConfig
+from .event_util import ENTITY_TYPES, EventUtil
 from .file_sink import FileSink
 
 logger = get_logger(__name__)
@@ -24,6 +25,10 @@ class BaseExtractor(ABC):
     def config_class() -> Type[BaseConfig]:
         """Returns the corresponding config class"""
 
+    @abstractmethod
+    async def extract(self, config: BaseConfig) -> Collection[ENTITY_TYPES]:
+        """Extract metadata and build messages, should be overridden"""
+
     def run(self, config: BaseConfig) -> List[MetadataChangeEvent]:
         """Callable function to extract metadata and send/post messages"""
         start_time = datetime.now()
@@ -31,21 +36,24 @@ class BaseExtractor(ABC):
 
         run_status = Status.SUCCESS
 
-        events: List[MetadataChangeEvent] = []
+        entities: Collection[ENTITY_TYPES] = []
         try:
-            events = asyncio.run(self.extract(config))
+            entities = asyncio.run(self.extract(config))
         except Exception as ex:
             run_status = Status.FAILURE
             logger.error(ex)
             traceback.print_exc()
 
         end_time = datetime.now()
-        entity_count = len(events)
+        entity_count = len(entities)
         logger.info(
             f"Extractor ended with {run_status} at {end_time}, fetched {entity_count} entities, took {format((end_time - start_time).total_seconds(), '.1f')}s"
         )
 
-        crawler_name = f"{self.__class__.__module__}.{self.__class__.__qualname__}"
+        crawler_name = EventUtil.class_fqcn(self.__class__)
+        event_util = EventUtil(crawler_name)
+        events = [event_util.build_event(entity) for entity in entities]
+
         run_metadata = CrawlerRunMetadata(
             crawler_name=crawler_name,
             start_time=start_time,
@@ -67,7 +75,3 @@ class BaseExtractor(ABC):
             file_sink.sink_logs()
 
         return events
-
-    @abstractmethod
-    async def extract(self, config: BaseConfig) -> List[MetadataChangeEvent]:
-        """Extract metadata and build messages, should be overridden"""
